==> v2_9_5.zip: kisyu.php <==
<?php
/*
kisyu([U[G[WFg,$_ENV["HTTP_X_PSP_BROWSER"]);
@@@@@@@@@@@@@@@@@@@@PSPp
n-b Ver 2np
*/
function kisyu($useragent,$psp) {
 $a = "Unknown";
 $b = "Unknown";
 $c = "Unknown";
 $au_data = file("au.txt");
 //tB[`[tHiʏj
 if (preg_match('/DoCoMo/', $useragent)){
 //DoCoMo/2.0 P06C(c500;TB;W24H16)
  $a = "docomo";
  preg_match('/DoCoMo\/(1.0|2.0) ([a-zA-Z0-9]+)/', $useragent, $match);
  $b = $match[2];
 }elseif (preg_match('/KDDI/', $useragent)){
 //KDDI-SH3B UP.Browser/6.2_7.2.7.1.K.3.352 (GUI) MMP/2.0
  $a = "au";
  preg_match('/KDDI\-([A-Z0-9]+)/', $useragent, $match);
  $b = $match[1];
  //擾foCXID@햼ɕϊ
  $af = 0;
  while($af < count($au_data)){
   $f = explode("<>",$au_data[$af]);
   $f2 = str_replace("\r","",str_replace("\n","",$f[1]));
   $b = str_replace($f2,$f[0],$b);
   $af++;
  }
 }elseif (preg_match('/J-PHONE|Vodafone|SoftBank/', $useragent)){
  //SoftBank/1.0/943SH/SHJ001/SN359302030689605 Browser/NetFront/3.5 Profile/MIDP-2.0 Configuration/CLDC-1.1
  $a = "SoftBank";
  $id = explode("/",$useragent);
  $b = $id[2];
 }elseif (preg_match('/WILLCOM/', $useragent, $match)){
  //Mozilla/3.0(WILLCOM;KYOCERA/WX300K/2;2.0.9.11.000000/0.1/C100) Opera/7.0
  $a = "Willcom";
  $id = explode("/",$useragent);
  $b = $id[2];
 //tB[`[tHituEUj
 }elseif (preg_match('/FOMA/', $useragent)){
  //Mozilla/4.08 (N906imyu_W;FOMA;c500;TB)
  $a = "docomo";
  preg_match('/Mozilla\/(\d+\.\d+) \(([a-zA-Z0-9]+)/', $useragent, $match);
  $b = $match[2]."(tuEU)";
 }elseif ($a == "au"){
  if (preg_match("/(Opera|BREW)/", $useragent)){
   preg_match("/KDDI\-([a-zA-Z0-9]+)/", $useragent, $match);
   $b = $match[1];
   $af = 0;
   while($af < count($au_data)){
    $f = explode("<>",$au_data[$af]);
    $f2 = str_replace("\r","",str_replace("\n","",$f[1]));
    $b = str_replace($f2,$f[0],$b);
    $af++;
   }
   $b = $b."(tuEU)";
  }
 }elseif ($a == "SoftBank"){
  if (preg_match("/(NetFront)/", $useragent)){
  //Mozilla/4.08 (815T;SoftBank) NetFront/3.3
  preg_match("/Mozilla\/(\d+\.\d+) \(([a-zA-Z0-9]+)/", $useragent, $match);
  $b = $match[1]."(tuEU)";
  }
 //X}[gtH (iPhone/iPod/iPad)
 }elseif (preg_match("/(iPhone|iPod|iPad)/", $useragent, $match)){
  $a = $match[0];
  $c = preg_match("/OS (\d+)(_\d+)(_\d+)/", $useragent, $match);
  $c = preg_match("/OS (\d+)(_\d+)/", $useragent, $match2);
  if ($match[1] != ""){
   $b = "iOS ".$match[1].".".$match[2].".".$match[3];
  }else{
   $b = "iOS ".$match2[1].".".$match2[2];
  }
  $b = str_replace("_","",$b);
 //X}[gtH (Android)
 }elseif (preg_match("/Android/", $useragent, $match)){
 if (preg_match("/Safari/", $useragent, $match)){
  $c = preg_match("/Android (\d+)(\.\d+)(\.\d+)/", $useragent, $match);
  //Build
  $a = "Android ".$match[1].$match[2];
  if ($match[3] != ""){ $a=$a.$match[3]; }
  preg_match("/(ja-jp;) (.+) Build/", $useragent, $math);
  if ($math[2] == ""){ preg_match("/(${a};) (.+) Build/", $useragent, $math); }
  $b = $math[2];
 //̑̃X}tH
 }elseif (preg_match("/BlackBerry/", $useragent, $match)){ $a = "BlackBerry"; }
 elseif (preg_match("/Windows Phone/", $useragent, $match)) { $a = "Windows Phone"; }
 //Q[@
 }elseif (preg_match("/PSP/", $useragent, $match)){
  $a = "Sony";
  preg_match("/system=(\d+)\.(\d+)/",$d,$ch);
  $b = "PSP ".$ch[1].".".$ch[2];
 }elseif (preg_match("/PlayStation Vita/", $useragent, $match)){ $a = "Sony"; $b = "PlayStation Vita";
 }elseif (preg_match("/PLAYSTATION 3/", $useragent, $match)){ $a = "Sony"; $b = "PS3";
 }elseif (preg_match("/Nintendo Wii/", $useragent, $match)){ $a = "Nintendo"; $b = "Wii";
 }elseif (preg_match("/Nintendo 3DS/", $useragent, $match)){ $a = "Nintendo"; $b = "3DS";
 }elseif (preg_match("/Nintendo DSi/", $useragent, $match)){ $a = "Nintendo"; $b = "DSi"; }
 //p\R
 elseif (preg_match("/Windows/", $useragent)){
  $a = "Windows";
  if (preg_match("/95/", $useragent)){ $a = $a." 95"; }
  elseif (preg_match("/98/", $useragent)){ $a = $a." 98"; }
  elseif (preg_match("/98; Win 9x 4.90;/", $useragent)){ $a = $a." Me"; }
  elseif (preg_match("/NT 3.1/", $useragent)){ $a = $a." NT 3.1"; }
  elseif (preg_match("/NT 3.5/", $useragent)){ $a = $a." NT 3.5"; }
  elseif (preg_match("/NT 3.51/", $useragent)){ $a = $a." NT 3.51"; }
  elseif (preg_match("/NT 4.0/", $useragent)){ $a = $a." NT 4.0"; }
  elseif (preg_match("/NT 5.0/", $useragent)){ $a = $a." 2000"; }
  elseif (preg_match("/NT 5.1/", $useragent)){ $a = $a." XP"; }
  elseif (preg_match("/NT 5.2/", $useragent)){ $a = $a." XP 64bit"; }
  elseif (preg_match("/NT 6.0/", $useragent)){ $a = $a." Vista";}
  elseif (preg_match("/NT 6.1/", $useragent)){ $a = $a." 7"; }
  elseif (preg_match("/NT 6.2/", $useragent)){ $a = $a." 8"; }
 }
 elseif (preg_match("/Ubuntu;/", $useragent, $match)) { $a = "Ubuntu"; }
 elseif (preg_match("/(L|l)inux/", $useragent, $match)) { $a = "Linux"; }
 elseif (preg_match("/Mac/", $useragent)) { $a = "Mac"; }
 elseif (preg_match("/SunOS/", $useragent, $match)) { $a = "Solaris"; }
 elseif (preg_match("/Fedora/", $useragent, $match)) { $a = "Fedora"; }
 elseif (preg_match("/Symbian/", $useragent, $match)) { $a = "Symbian OS"; }
 elseif (preg_match("/FreeBSD/", $useragent, $match)) { $a = "FreeBSD"; }
 elseif (preg_match("/Debian/",$useragent)) { $a = "Debian"; }
 if (preg_match("/(WOW64|Win64|x86_64)/", $useragent)){ $a = $a." 64bit"; }
 //uEU
 if ($a == $c){if (preg_match("/NetFront/", $useragent, $match)) { $b = "NetFront"; }}
 elseif(preg_match("/MSIE/",$useragent)){
  preg_match("/MSIE (\d+)/", $useragent, $match);
  $b = "IE ".$match[1];
 }
 elseif(preg_match("/Firefox/",$useragent)){
  preg_match("/Firefox\/(\d+)/", $useragent, $match);
  $b = "Firefox ".$match[1];
 }
 elseif(preg_match("/Chrome/",$useragent)){
  preg_match("/Chrome\/(\d+)/", $useragent, $match);
  $b = "Chrome ".$match[1];
 }
 elseif(preg_match("/Opera/",$useragent)){
  preg_match("/Version\/(\d+\.\d+)/", $useragent, $match);
  preg_match("/Opera\/(\d+\.\d+)/", $useragent, $match2);
  if ($match[1] != ""){
   $b = "Opera ".$match[1];
  }else{
   $b = "Opera ".$match2[1];
  }
 }
 elseif(preg_match("/Sleipnir/",$useragent)){
  preg_match("/Sleipnir\/(\d+\.\d+)(\.\d+)/", $useragent, $match);
  $b = "Sleipnir ".$match[1].$match[2];
 }
 elseif(preg_match("/Lunascape/",$useragent)){
  preg_match("/Lunascape\/(\d+\.\d+)(\.\d+)/", $useragent, $match);
  $b = "Lunascape ".$match[1].$match[2];
 }
 elseif (preg_match("/Iron/", $useragent, $match)){ $b = "SRWare Iron"; }
 elseif (preg_match("/Navigator/", $useragent, $match)){ $b = "Netscape"; }
 elseif (preg_match("/Grani/", $useragent, $match)){ $b = "Grani"; }
 elseif (preg_match("/CoolNovo/", $useragent, $match)){ $b = "CoolNovo"; }
 elseif (preg_match("/PaleMoon/", $useragent, $match)){ $b = "PaleMoon"; }
 elseif (preg_match("/Puffin/", $useragent, $match)){ $b = "Puffin"; }
 elseif (preg_match("/Dolphin/", $useragent, $match)){ $b = "Dolphin"; $dol = 1; }
 elseif (preg_match("/InettvBrowser/", $useragent, $match)){ $b = "InettvBrowser"; }
 elseif (preg_match("/Konqueror/", $useragent, $match)){ $b = "Konqueror"; }
 elseif (preg_match("/Netscape/", $useragent, $match)){ $b = "Netscape"; }
 elseif (preg_match("/Iceweasel/", $useragent, $match)){ $b = "Iceweasel"; }
//InettvBrowser (Ɠd)
if (preg_match("/InettvBrowser/", $b, $match)){
 $a = "TV";
 preg_match("/InettvBrowser\/(\d+)\.(\d+)/", $ua, $match);
 $b = "InettvBrowser ".$match[1].".".$match[2];
}
//2chuEU
if (preg_match("/BB2C/", $useragent, $match)){ $b = "BB2C"; }
//bot
if (preg_match("/bingbot/", $useragent, $match)){ $a = "Bing"; $b = "Bot"; }
if (preg_match("/BingPreview/", $useragent, $match)){ $a = "Bing"; $b = "Bot"; }
if (preg_match("/NHN Corp./", $useragent, $match)){ $a = "Naver"; $b = "Bot"; }
if (preg_match("/Googlebot/", $useragent, $match)){ $a = "Google"; $b = "Bot"; }
if (preg_match("/Y!J-BRJ\/YATS/", $useragent, $match)){ $a = "Yahoo"; $b = "Bot"; }
if (preg_match("/Y!J-BRL\/YATSS/", $useragent, $match)){ $a = "Yahoo"; $b = "Bot"; }
if (preg_match("/Y!J-BRM\/YATSD/", $useragent, $match)){ $a = "Yahoo"; $b = "Bot"; }
if (preg_match("/Y!J-BRN\/YATSA/", $useragent, $match)){ $a = "Yahoo"; $b = "Bot"; }
if (preg_match("/Yahoo! Slurp/", $useragent, $match)){ $a = "Yahoo"; $b = "Bot"; }
if (preg_match("/Baiduspider/", $useragent, $match)){ $a = "Baidu"; $b = "Bot"; }
if (preg_match("/Twitterbot/", $useragent, $match)){ $a = "Twitter"; $b = "Bot"; }
if (preg_match("/Anonymouse.org/", $useragent, $match)){ $a = "Anonymouse.org"; $b = "Bot"; }
if (preg_match("/TweetmemeBot/", $useragent, $match)){ $a = "Twitter"; $b = "Bot"; }
if (preg_match("/mixi\-check/", $useragent, $match)){ $a = "mixi"; $b = "Bot"; }
if (preg_match("/gnip\.com/", $useragent, $match)){ $a = "Gnip"; $b = "Bot"; }
if (preg_match("/metauri\.com/", $useragent, $match)){ $a = "MetaURI"; $b = "Bot"; }
if (preg_match("/Butterfly/", $useragent, $match)){ $a = "Topsy Labs"; $b = "Bot"; }
if (preg_match("/Voyager/", $useragent, $match)){ $a = "Voyager"; $b = "Bot"; }
if (preg_match("/PaperLiBot/", $useragent, $match)){ $a = "Paper.li"; $b = "Bot"; }
if (preg_match("/YandexBot/", $useragent, $match)){ $a = "Yandex"; $b = "Bot"; }
if (preg_match("/msnbot/", $useragent, $match)){ $a = "msn"; $b = "Bot"; }
if (preg_match("/facebookexternalhit/", $useragent, $match)){ $a = "Facebook"; $b = "Bot"; }
if (preg_match("/Crowsnest/", $useragent, $match)){ $a = "Crowsnest"; $b = "Bot"; }
if (preg_match("/HeartRails_Capture/", $useragent, $match)){ $a = "HeartRails Capture"; $b = "Bot"; }
if (preg_match("/AhrefsBot/", $useragent, $match)){ $a = "Ahrefs"; $b = "Bot"; }
if (preg_match("/cboc\-test@lab\.ntt\.co\.jp/", $useragent, $match)){ $a = "NTT"; $b = "Bot"; }
if (preg_match("/dom2dom/", $useragent, $match)){ $a = "dom2dom"; $b = "Bot"; }
if (preg_match("/Ezooms/", $useragent, $match)){ $a = "Ezooms"; $b = "Bot"; }
if (preg_match("/ichiro/", $useragent, $match)){ $a = "goo"; $b = "ichiro Bot"; }
if (preg_match("/SurveyBot/", $useragent, $match)){ $a = "SurveyBot"; $b = "Bot"; }
if (preg_match("/http:\/\/www.rcdtokyo.com\/pc2m\//", $useragent, $match)){ $a = "PC2M"; $b = "PC2M"; }
if (preg_match("/Froute Mobile Gateway/", $useragent, $match)){ $a = "PC2M"; $b = "froute.jp BroadBand Gateway"; }
if (preg_match("/mfc2/", $useragent, $match)){ $a = "FC2"; $b = "FC2gѕϊ"; }
if (preg_match("/mobazilla/", $useragent, $match)){ $a = "mobazilla"; $b = "gѕϊ"; }
if (preg_match("/Google Wireless Transcoder/", $useragent, $match)){ $a = "Google"; $b = "Google Wireless Transcoder"; }
if (preg_match("/Google Web Preview/", $useragent, $match)){ $a = "Google"; $b = "Google Web Preview"; }
if (preg_match("/MLBot/", $useragent, $match)){ $a = "MLBot"; $b = "bot"; }
if (preg_match("/Catapiller/", $useragent, $match)){ $a = "Twitter"; $b = "Catapiller"; }
if (preg_match("/WBSearchBot/", $useragent, $match)){ $a = "WBSearch"; $b = "Bot"; }
if (preg_match("/Steeler/", $useragent, $match)){ $a = "Steeler"; $b = "Bot"; }
if (preg_match("/360Spider/", $useragent, $match)){ $a = "360Spider"; $b = "Bot"; }
//CGI
if (preg_match("/Python/", $useragent, $match)){ $a = "CGI"; $b = "Python"; }

return array($a,$b);
}

==> 3_0.zip: kisyu.php <==
<?php
/*
kisyu([U[G[WFg,$_ENV["HTTP_X_PSP_BROWSER"]);
@@@@@@@@@@@@@@@@@@@@PSPp
n-b Ver 2np
*/
function kisyu($useragent,$psp) {
 $a = "Unknown";
 $b = "Unknown";
 $c = "Unknown";
 $au_data = file("au.txt");
 //tB[`[tHiʏj
 if (preg_match('/DoCoMo/', $useragent)){
 //DoCoMo/2.0 P06C(c500;TB;W24H16)
  $a = "docomo";
  preg_match('/DoCoMo\/(1.0|2.0) ([a-zA-Z0-9]+)/', $useragent, $match);
  $b = $match[2];
 }elseif (preg_match('/KDDI/', $useragent)){
 //KDDI-SH3B UP.Browser/6.2_7.2.7.1.K.3.352 (GUI) MMP/2.0
  $a = "au";
  preg_match('/KDDI\-([A-Z0-9]+)/', $useragent, $match);
  $b = $match[1];
  //擾foCXID@햼ɕϊ
  $af = 0;
  while($af < count($au_data)){
   $f = explode("<>",$au_data[$af]);
   $f2 = str_replace("\r","",str_replace("\n","",$f[1]));
   $b = str_replace($f2,$f[0],$b);
   $af++;
  }
 }elseif (preg_match('/J-PHONE|Vodafone|SoftBank/', $useragent)){
  //SoftBank/1.0/943SH/SHJ001/SN359302030689605 Browser/NetFront/3.5 Profile/MIDP-2.0 Configuration/CLDC-1.1
  $a = "SoftBank";
  $id = explode("/",$useragent);
  $b = $id[2];
 }elseif (preg_match('/WILLCOM/', $useragent, $match)){
  //Mozilla/3.0(WILLCOM;KYOCERA/WX300K/2;2.0.9.11.000000/0.1/C100) Opera/7.0
  $a = "Willcom";
  $id = explode("/",$useragent);
  $b = $id[2];
 //tB[`[tHituEUj
 }elseif (preg_match('/FOMA/', $useragent)){
  //Mozilla/4.08 (N906imyu_W;FOMA;c500;TB)
  $a = "docomo";
  preg_match('/Mozilla\/(\d+\.\d+) \(([a-zA-Z0-9]+)/', $useragent, $match);
  $b = $match[2]."(tuEU)";
 }elseif ($a == "au"){
  if (preg_match("/(Opera|BREW)/", $useragent)){
   preg_match("/KDDI\-([a-zA-Z0-9]+)/", $useragent, $match);
   $b = $match[1];
   $af = 0;
   while($af < count($au_data)){
    $f = explode("<>",$au_data[$af]);
    $f2 = str_replace("\r","",str_replace("\n","",$f[1]));
    $b = str_replace($f2,$f[0],$b);
    $af++;
   }
   $b = $b."(tuEU)";
  }
 }elseif ($a == "SoftBank"){
  if (preg_match("/(NetFront)/", $useragent)){
  //Mozilla/4.08 (815T;SoftBank) NetFront/3.3
  preg_match("/Mozilla\/(\d+\.\d+) \(([a-zA-Z0-9]+)/", $useragent, $match);
  $b = $match[1]."(tuEU)";
  }
 //X}[gtH (iPhone/iPod/iPad)
 }elseif (preg_match("/(iPhone|iPod|iPad)/", $useragent, $match)){
  $a = $match[0];
  $c = preg_match("/OS (\d+)(_\d+)(_\d+)/", $useragent, $match);
  $c = preg_match("/OS (\d+)(_\d+)/", $useragent, $match2);
  if ($match[1] != ""){
   $b = "iOS ".$match[1].".".$match[2].".".$match[3];
  }else{
   $b = "iOS ".$match2[1].".".$match2[2];
  }
  $b = str_replace("_","",$b);
 //X}[gtH (Android)
 }elseif (preg_match("/Android/", $useragent, $match)){
  $a = "Android";
  if (preg_match("/Safari/", $useragent, $match)){
   $c = preg_match("/Android (\d+)(\.\d+)(\.\d+)/", $useragent, $match);
   //Build
   $a = "Android ".$match[1].$match[2];
   if ($match[3] != ""){ $a=$a.$match[3]; }
   preg_match("/(ja-jp;) (.+) Build/", $useragent, $math);
   if ($math[2] == ""){ preg_match("/(${a};) (.+) Build/", $useragent, $math); }
   $b = $math[2];
 //̑̃X}tH
 }elseif (preg_match("/BlackBerry/", $useragent, $match)){ $a = "BlackBerry"; }
 elseif (preg_match("/Windows Phone/", $useragent, $match)) { $a = "Windows Phone"; }
 //Q[@
 }elseif (preg_match("/PSP/", $useragent, $match)){
  $a = "Sony";
  preg_match("/system=(\d+)\.(\d+)/",$psp,$ch);
  $b = "PSP ".$ch[1].".".$ch[2];
 }elseif (preg_match("/PlayStation Vita/", $useragent, $match)){ $a = "Sony"; $b = "PlayStation Vita";
 }elseif (preg_match("/PLAYSTATION 3/", $useragent, $match)){ $a = "Sony"; $b = "PS3";
 }elseif (preg_match("/Nintendo Wii/", $useragent, $match)){ $a = "Nintendo"; $b = "Wii";
 }elseif (preg_match("/Nintendo 3DS/", $useragent, $match)){ $a = "Nintendo"; $b = "3DS";
 }elseif (preg_match("/Nintendo DSi/", $useragent, $match)){ $a = "Nintendo"; $b = "DSi"; }
 //p\R
 elseif (preg_match("/Windows/", $useragent)){
  $a = "Windows";
  if (preg_match("/95/", $useragent) and !preg_match("/NT 6.2/", $useragent)){ $a = $a." 95"; }
  elseif (preg_match("/98/", $useragent)){ $a = $a." 98"; }
  elseif (preg_match("/98; Win 9x 4.90;/", $useragent)){ $a = $a." Me"; }
  elseif (preg_match("/NT 3.1/", $useragent)){ $a = $a." NT 3.1"; }
  elseif (preg_match("/NT 3.5/", $useragent)){ $a = $a." NT 3.5"; }
  elseif (preg_match("/NT 3.51/", $useragent)){ $a = $a." NT 3.51"; }
  elseif (preg_match("/NT 4.0/", $useragent)){ $a = $a." NT 4.0"; }
  elseif (preg_match("/NT 5.0/", $useragent)){ $a = $a." 2000"; }
  elseif (preg_match("/NT 5.1/", $useragent)){ $a = $a." XP"; }
  elseif (preg_match("/NT 5.2/", $useragent)){ $a = $a." XP 64bit"; }
  elseif (preg_match("/NT 6.0/", $useragent)){ $a = $a." Vista";}
  elseif (preg_match("/NT 6.1/", $useragent)){ $a = $a." 7"; }
  elseif (preg_match("/NT 6.2/", $useragent)){ $a = $a." 8"; }
  elseif (preg_match("/NT 6.3/", $useragent)){ $a = $a." 8.1"; }
 }
 elseif (preg_match("/Ubuntu;/", $useragent, $match)) { $a = "Ubuntu"; }
 elseif (preg_match("/(L|l)inux/", $useragent, $match)) { $a = "Linux"; }
 elseif (preg_match("/Mac/", $useragent)) { $a = "Mac"; }
 elseif (preg_match("/SunOS/", $useragent, $match)) { $a = "Solaris"; }
 elseif (preg_match("/Fedora/", $useragent, $match)) { $a = "Fedora"; }
 elseif (preg_match("/Symbian/", $useragent, $match)) { $a = "Symbian OS"; }
 elseif (preg_match("/FreeBSD/", $useragent, $match)) { $a = "FreeBSD"; }
 elseif (preg_match("/Debian/",$useragent)) { $a = "Debian"; }
 elseif (preg_match("/redhat/",$useragent)) { $a = "Red Hat"; }
 if (preg_match("/(WOW64|Win64|x86_64)/", $useragent)){ $a = $a." 64bit"; }
 //uEU
 if ($a == $c){if (preg_match("/NetFront/", $useragent, $match)) { $b = "NetFront"; }}
 elseif(preg_match("/MSIE/",$useragent)){
  preg_match("/MSIE (\d+)/", $useragent, $match);
  $b = "IE ".$match[1];
 }
 elseif(preg_match("/Trident\/7/",$useragent)){//IE 11b
  preg_match("/rv:(\d+)/", $useragent, $match);
  $b = "IE ".$match[1];
 }
 elseif(preg_match("/Firefox/",$useragent)){
  preg_match("/Firefox\/(\d+)/", $useragent, $match);
  $b = "Firefox ".$match[1];
 }
 elseif(preg_match("/Chrome/",$useragent) and !preg_match("/OPR/",$useragent)){
  preg_match("/Chrome\/(\d+)/", $useragent, $match);
  $b = "Chrome ".$match[1];
 }
 elseif(preg_match("/Opera/",$useragent) and $b == $c or preg_match("/OPR/",$useragent)){
  preg_match("/Version\/(\d+\.\d+)/", $useragent, $match);
  preg_match("/Opera\/(\d+\.\d+)/", $useragent, $match2);
  preg_match("/OPR\/(\d+\.\d+)/", $useragent, $match3);
  if ($match[1] != ""){
   $b = "Opera ".$match[1];
  }elseif ($match[2] != ""){
   $b = "Opera ".$match2[1];
  }else{
   $b = "Opera ".$match3[1];
  }
 }
 elseif(preg_match("/Sleipnir/",$useragent)){
  preg_match("/Sleipnir\/(\d+\.\d+)(\.\d+)/", $useragent, $match);
  $b = "Sleipnir ".$match[1].$match[2];
 }
 elseif(preg_match("/Lunascape/",$useragent)){
  preg_match("/Lunascape\/(\d+\.\d+)(\.\d+)/", $useragent, $match);
  $b = "Lunascape ".$match[1].$match[2];
 }
 elseif (preg_match("/Iron/", $useragent, $match)){ $b = "SRWare Iron"; }
 elseif (preg_match("/Navigator/", $useragent, $match)){ $b = "Netscape"; }
 elseif (preg_match("/Grani/", $useragent, $match)){ $b = "Grani"; }
 elseif (preg_match("/CoolNovo/", $useragent, $match)){ $b = "CoolNovo"; }
 elseif (preg_match("/PaleMoon/", $useragent, $match)){ $b = "PaleMoon"; }
 elseif (preg_match("/Puffin/", $useragent, $match)){ $b = "Puffin"; }
 elseif (preg_match("/Dolphin/", $useragent, $match)){ $b = "Dolphin"; $dol = 1; }
 elseif (preg_match("/InettvBrowser/", $useragent, $match)){ $b = "InettvBrowser"; }
 elseif (preg_match("/Konqueror/", $useragent, $match)){ $b = "Konqueror"; }
 elseif (preg_match("/Netscape/", $useragent, $match)){ $b = "Netscape"; }
 elseif (preg_match("/Iceweasel/", $useragent, $match)){ $b = "Iceweasel"; }
 elseif (preg_match("/Safari/", $useragent, $match) and $b == $c){ $b = "Safari"; }
//InettvBrowser (Ɠd)
if (preg_match("/InettvBrowser/", $b, $match)){
 $a = "TV";
 preg_match("/InettvBrowser\/(\d+)\.(\d+)/", $ua, $match);
 $b = "InettvBrowser ".$match[1].".".$match[2];
}
//2chuEU
if (preg_match("/BB2C/", $useragent, $match)){ $b = "BB2C"; }
//bot
if (preg_match("/bingbot/", $useragent, $match)){ $a = "Bing"; $b = "Bot"; }
if (preg_match("/BingPreview/", $useragent, $match)){ $a = "Bing"; $b = "Bot"; }
if (preg_match("/NHN Corp./", $useragent, $match)){ $a = "Naver"; $b = "Bot"; }
if (preg_match("/Googlebot/", $useragent, $match)){ $a = "Google"; $b = "Bot"; }
if (preg_match("/Y!J-BRJ\/YATS/", $useragent, $match)){ $a = "Yahoo"; $b = "Bot"; }
if (preg_match("/Y!J-BRL\/YATSS/", $useragent, $match)){ $a = "Yahoo"; $b = "Bot"; }
if (preg_match("/Y!J-BRM\/YATSD/", $useragent, $match)){ $a = "Yahoo"; $b = "Bot"; }
if (preg_match("/Y!J-BRN\/YATSA/", $useragent, $match)){ $a = "Yahoo"; $b = "Bot"; }
if (preg_match("/Yahoo! Slurp/", $useragent, $match)){ $a = "Yahoo"; $b = "Bot"; }
if (preg_match("/Baiduspider/", $useragent, $match)){ $a = "Baidu"; $b = "Bot"; }
if (preg_match("/Twitterbot/", $useragent, $match)){ $a = "Twitter"; $b = "Bot"; }
if (preg_match("/Anonymouse.org/", $useragent, $match)){ $a = "Anonymouse.org"; $b = "Bot"; }
if (preg_match("/TweetmemeBot/", $useragent, $match)){ $a = "Twitter"; $b = "Bot"; }
if (preg_match("/mixi\-check/", $useragent, $match)){ $a = "mixi"; $b = "Bot"; }
if (preg_match("/gnip\.com/", $useragent, $match)){ $a = "Gnip"; $b = "Bot"; }
if (preg_match("/metauri\.com/", $useragent, $match)){ $a = "MetaURI"; $b = "Bot"; }
if (preg_match("/Butterfly/", $useragent, $match)){ $a = "Topsy Labs"; $b = "Bot"; }
if (preg_match("/Voyager/", $useragent, $match)){ $a = "Voyager"; $b = "Bot"; }
if (preg_match("/PaperLiBot/", $useragent, $match)){ $a = "Paper.li"; $b = "Bot"; }
if (preg_match("/YandexBot/", $useragent, $match)){ $a = "Yandex"; $b = "Bot"; }
if (preg_match("/msnbot/", $useragent, $match)){ $a = "msn"; $b = "Bot"; }
if (preg_match("/facebookexternalhit/", $useragent, $match)){ $a = "Facebook"; $b = "Bot"; }
if (preg_match("/Crowsnest/", $useragent, $match)){ $a = "Crowsnest"; $b = "Bot"; }
if (preg_match("/HeartRails_Capture/", $useragent, $match)){ $a = "HeartRails Capture"; $b = "Bot"; }
if (preg_match("/AhrefsBot/", $useragent, $match)){ $a = "Ahrefs"; $b = "Bot"; }
if (preg_match("/cboc\-test@lab\.ntt\.co\.jp/", $useragent, $match)){ $a = "NTT"; $b = "Bot"; }
if (preg_match("/dom2dom/", $useragent, $match)){ $a = "dom2dom"; $b = "Bot"; }
if (preg_match("/Ezooms/", $useragent, $match)){ $a = "Ezooms"; $b = "Bot"; }
if (preg_match("/ichiro/", $useragent, $match)){ $a = "goo"; $b = "ichiro Bot"; }
if (preg_match("/SurveyBot/", $useragent, $match)){ $a = "SurveyBot"; $b = "Bot"; }
if (preg_match("/http:\/\/www.rcdtokyo.com\/pc2m\//", $useragent, $match)){ $a = "PC2M"; $b = "PC2M"; }
if (preg_match("/Froute Mobile Gateway/", $useragent, $match)){ $a = "PC2M"; $b = "froute.jp BroadBand Gateway"; }
if (preg_match("/mfc2/", $useragent, $match)){ $a = "FC2"; $b = "FC2gѕϊ"; }
if (preg_match("/mobazilla/", $useragent, $match)){ $a = "mobazilla"; $b = "gѕϊ"; }
if (preg_match("/Google Wireless Transcoder/", $useragent, $match)){ $a = "Google"; $b = "Google Wireless Transcoder"; }
if (preg_match("/Google Web Preview/", $useragent, $match)){ $a = "Google"; $b = "Google Web Preview"; }
if (preg_match("/MLBot/", $useragent, $match)){ $a = "MLBot"; $b = "bot"; }
if (preg_match("/Catapiller/", $useragent, $match)){ $a = "Twitter"; $b = "Catapiller"; }
if (preg_match("/WBSearchBot/", $useragent, $match)){ $a = "WBSearch"; $b = "Bot"; }
if (preg_match("/Steeler/", $useragent, $match)){ $a = "Steeler"; $b = "Bot"; }
if (preg_match("/360Spider/", $useragent, $match)){ $a = "360Spider"; $b = "Bot"; }
if (preg_match("/MJ12bot/", $useragent, $match)){ $a = "Majestic-12"; $b = "Bot"; }
if (preg_match("/JS-Kit URL Resolver/", $useragent, $match)){ $a = "JS-Kit URL Resolver"; $b = "Bot"; }
if (preg_match("/NING/", $useragent, $match)){ $a = "NING"; $b = "Bot"; }

//CGI
if (preg_match("/Python/", $useragent, $match)){ $a = "CGI"; $b = "Python"; }
//̑
if (preg_match("/Java\/(\d+)\.(\d+)\.(\d+)_(\d+)/", $useragent, $match)){ $a = "Java"; $b = "Version {$match[1]}.{$match[2]}.{$match[3]} Update {$match[4]}"; }

return array($a,$b);
}
